@@ -28,6 +28,7 @@
 #include <glade/glade.h>
 #include "file-utils.h"
 #include "fr-process.h"
+#include "fr-stock.h"
 #include "gconf-utils.h"
 #include "window.h"
 #include "typedefs.h"
@@ -115,11 +116,9 @@ int main (int argc, char **argv)
                 g_error ("Cannot initialize the Virtual File System.");
 
 	glade_gnome_init ();
-
+	fr_stock_init ();
 	init_session (argv);
-
 	initialize_data ();
-
 	prepare_app (pctx);
 	poptFreeContext (pctx);
 
@@ -359,7 +358,7 @@ prepare_app (poptContext pctx)
 		FRWindow    *window;
 		GList       *file_list = NULL;
 		const char  *filename;
-		
+
 		window = window_new ();
 		if (default_dir != NULL)
 			window_set_default_dir (window, default_dir);
@@ -383,7 +382,7 @@ prepare_app (poptContext pctx)
 		file_list = g_list_reverse (file_list);
 		
 		window_archive__open_add (window, add_to_path, file_list);
-		window_archive__close (window);
+		window_archive__quit (window);
 		window_batch_mode_start (window);
 
 	} else if ((extract_to != NULL) || (extract == 1)) { /* Extract all archives. */
@@ -399,7 +398,7 @@ prepare_app (poptContext pctx)
 			window_archive__open_extract (window, 
 						      archive, 
 						      extract_to_path);
-		window_archive__close (window);
+		window_archive__quit (window);
 		window_batch_mode_start (window);
 
 	} else { /* Open each archives in a window */
